# SymphonyDuplicates

A component that displays data duplicates based on a column prefixed `duplicates_`.
This column must contain lists of numbers that signal which duplicate group an item belongs to.
